#include "GameGirl.h"
#include "LCD.h"
#include "Sokoban.h"
#include "p18f452.h"
#include <delays.h>
#include <adc.h>
#include "Font_5x7.h"

/* Initialisation de l'afficheur */
void LCD_Init (void) {
	
	// Slection des deux controleurs
	LCD_CSA = LCD_CSB = 1;	
// dsactivation de enable
	LCD_Enable = 0;			
// Reset  0
	LCD_Reset = 0;	
// Attente de 100 cycles	
	Delay100TCYx (1);	
// Mettre Reset  1
	LCD_Reset = 1;			
// Allumage de l'afficheur
	LCD_Write_Command(0b00111111); 	

}


/* Fonction qui envoie l'instruction DATA vers l'afficheur */
void LCD_Write_Command (unsigned char Data)
 {
	
// Registre en mode criture
	LCD_RS = LCD_RW = 0;
// Placer la donne sur le port
	PORTD = Data;
// Attendre 200 cycles
	Delay100TCYx (2);
// Activer Enable
	LCD_Enable = 1;
// Attendre 200 cycles 
	Delay100TCYx (2);
// Dsactiver Enable
	LCD_Enable = 0;		
}



/* Fonction qui envoie la donne  afficher */
void LCD_Send_Data (unsigned char Data) {
// Registre en mode criture
	LCD_RS = 1;
	LCD_RW = 0;
// Placer la donne sur le port
	PORTD = Data;
// Attendre 200 cycles
	Delay100TCYx (2);
// Enable  1
	LCD_Enable = 1;
// Attendre 200 cycles 
	Delay100TCYx (2);
// Enable  0
	LCD_Enable = 0;	
}




/* Fonction qui efface tout ce que contient l'cran */
void LCD_Clear (void) {
	unsigned char x = 0;
	unsigned char y = 0;
//Slection des deux controleurs
	LCD_CSA = LCD_CSB = 1;
// Avancer dans les 7 pages
	for (x=0; x<8; x++){
// Choix de la page
		LCD_Write_Command (0xb8 + x);
// Pour tout les octets
		for (y=0; y<64; y++){
// Envoi d'un octet nul
			LCD_Send_Data (0x00);
		}
	}
}


/* Placement du curseur */
void LCD_GotoXY (unsigned char X, unsigned char Y)
{
	if (X<64) {
		LCD_CSA = 0 ;		// Dsactivation de l'afficheur A
		LCD_CSB = 1 ; 		// Slection de l'afficheur B
// Slection de la page 
		LCD_Write_Command (0xB8+Y);
// Place le curseur  l'adresse X
		LCD_Write_Command (0x40+X);
	}
	else {
		LCD_CSA = 1 ;		// Slection de l'afficheur A
		LCD_CSB = 0 ; 		// Dsactivation de l'afficheur B
// Slection de la page 
		LCD_Write_Command (0xB8+Y);
// Place le curseur  l'adresse X
		LCD_Write_Command (X);	
		LCD_Write_Command ((0x40+X)-64);	
	}
}



// Fonction d'affichage d'un caractre
void LCD_Putchar(unsigned char ch)
{ 
	unsigned char i;
	for(i=0;i!=5;i++)
// Envoi du caractre en ASCII
		LCD_Send_Data(Font[((unsigned int)ch-FONT_MIN)*5+i]); 
// Envoi d'un octet vide => espace
		LCD_Send_Data(0x00);
// Attente		
	Delay10KTCYx(10);		
}


// Lecture des 8 bits courant de la mmoire video
char LCD_ReadData(void)
{ unsigned char data;
// Mis en entre du port D
	TRISD = 0b11111111;		
	LCD_RS= LCD_RW= 1;
	LCD_Enable=1;
	Delay10TCYx(5);
	LCD_Enable=0;
// Lecture de la donne en entre
	data=LCD_DATA;			
// Mis en sortie du port D
	TRISD = 0b00000000;		
// Retourner la valeur
	return data;		
}



// Allume un pixel - horizontal
void LCD_PixelOnHori (unsigned char X, unsigned char Y){
	unsigned char Val, page=Y>>3;
// Placer le curseur sur l'octet
	LCD_GotoXY (X, page);
// Lecture de l'octet
	Val=LCD_ReadData();
	Val|=0x01<<(Y-page*8);
// Placer le curseur
	LCD_GotoXY(X,page);
// Envoi de la donnee
	LCD_Send_Data(Val);
}


// Allume un pixel - verticale
void LCD_PixelOnVert (unsigned char X, unsigned char Y){
	unsigned char Val, page=Y>>3;
// Placer le curseur sur l'octet
	LCD_GotoXY (X, page);
// Placer le curseur
	LCD_GotoXY(X,page);
// Envoi de la donnee
	LCD_Send_Data(0xFF);
}


// Efface un pixel
void LCD_PixelOff (unsigned char X, unsigned char Y){
	unsigned char Val, Var, page=Y>>3;
// Placer le curseur sur l'octet
	LCD_GotoXY (X, page);
// Lecture de l'octet
	Val=LCD_ReadData();
//Selection du pixel
	Var=0x01<<(Y-page*8);
//Complementer
	Var=~Var;
// Pixel choisi à 0
	Var&=Var;
// Placer le curseur
	LCD_GotoXY(X,page);
// Envoi de la donnee
	LCD_Send_Data(Val);
}