#include "GameGirl.h"
#include "LCD.h"
#include "Sokoban.h"
#include "p18f452.h"
#include <adc.h>
#include <delays.h>

// Definition de la cible
const char Cible [8] =
{0x00, 0x18, 0x3C, 0x7E, 0x7E, 0x3C, 0x18, 0x00};

// Definition de la caisse
const char Caisse [8] =
{0x00, 0x7E, 0x66, 0x5A, 0x5A, 0x66, 0x7E, 0x00};

// Definition du joueur
const char Joueur [8] =
{0x3C, 0x42, 0x95, 0xA1, 0xA1, 0x95, 0x42, 0x3C};



void CreerObjet (const char Objet [8])
{
	unsigned char i;
	for (i=0; i<8; i++)
		LCD_Send_Data(Objet [i]);
}

void EffacerObjet (unsigned char X, unsigned char Y, const char Objet[8])
{
	unsigned char i=0;
// Effacer l'ancien objet
	LCD_GotoXY (X,Y);
	for (i=0; i<8; i++)
		LCD_Send_Data(0x00);
}

void BougerObjet (unsigned char X, unsigned char Y, const char Objet [8])
{
	unsigned char i=0;
// Mettre l'objet une case plus loin
	LCD_GotoXY (X,Y);
	for (i=0; i<8; i++)
		LCD_Send_Data (Objet [i]);
}


// Trace une ligne horizontale
void TraceHori (unsigned char Xdebut, unsigned char Xfin, unsigned char Y)
{
	unsigned char i=0;
	for (i=Xdebut; i<Xfin; i++)
		LCD_PixelOnHori(i,Y);
}

// Trace une ligne verticale
void TraceVert (unsigned char Ydebut, unsigned char Yfin, unsigned char X)
{
	unsigned char i=0;
	for (i=Ydebut; i<Yfin; i++)
		LCD_PixelOnVert(X,i);
}


// Fonction de l'ecran d'intro
void Intro (void)
{
	unsigned char i=0;
	unsigned char Titre [8] = {' ','S','O','K','O','B','A','N'};
	unsigned char Vert [8] = {' ',' ','v','e','r','t',' ',' '};
	
	TraceHori (0, 128, 22);
	TraceHori (0, 128, 32);

	LCD_GotoXY(12,3); 
	for (i=0; i<8; i++)
		LCD_Putchar(Titre[i]);
	LCD_GotoXY(64,7);
	for (i=0; i<8; i++)
		LCD_Putchar(Vert[i]);
}

// Fonction instruction
void Instruction (void)
{
	unsigned char i=0;
	unsigned char Expli [8] = {' ',' ','E','X','P','L','I', 'C'};
	unsigned char Cation [8] = {'A','T','I','O','N','S',' ', ' '};
	unsigned char Passer [8] = {' ',' ','P','A','S','S','E','R'};
	unsigned char Niveau [8] = {' ',' ','N','I','V','E','A','U'};
	unsigned char Rouge [8] = {'r', 'o','u','g','e',' ',' ',' '};
	unsigned char Again [8] = {' ', ' ', ' ','A', 'G', 'A', 'I', 'N'};
	unsigned char Jaune [8] = {'j','a','u','n','e',' ',' ',' '};
	unsigned char Start [8] = {' ', ' ', ' ', 'S', 'T', 'A', 'R', 'T'};
	unsigned char Vert [8] = {'v','e','r','t',' ',' ',' ',' '};


	LCD_GotoXY(16,0); 
	for (i=0; i<8; i++)
		LCD_Putchar(Expli[i]);
	LCD_GotoXY(64,0);
	for (i=0; i<8; i++)
		LCD_Putchar(Cation[i]);
	LCD_GotoXY(1,2); 
	for (i=0; i<8; i++)
		LCD_Putchar(Passer[i]);
	LCD_GotoXY(1,3); 
	for (i=0; i<8; i++)
		LCD_Putchar(Niveau[i]);
	LCD_GotoXY(64,2);
	for (i=0; i<8; i++)
		LCD_Putchar(Rouge[i]);
/*	LCD_GotoXY(1,4);
	for (i=0; i<8; i++)
		LCD_Putchar(Again[i]);
	LCD_GotoXY(64,4);
	for (i=0; i<8; i++)
		LCD_Putchar(Jaune[i]);*/
	LCD_GotoXY(1,6);
	for (i=0; i<8; i++)
		LCD_Putchar(Start[i]);
	LCD_GotoXY(64,6);
	for (i=0; i<8; i++)
		LCD_Putchar(Vert[i]);
}

// Fonction Felicitation
void Felicitation (void)
{
	unsigned char i=0;
	unsigned char Felici [8] = {' ', ' ','F','E','L','I','C','I'};
	unsigned char Tation [8] = {'T','A','T','I','O','N',' ',' '};


	LCD_GotoXY(16,4); 
	for (i=0; i<8; i++)
		LCD_Putchar(Felici[i]);
	LCD_GotoXY(64,4);
	for (i=0; i<8; i++)
		LCD_Putchar(Tation[i]);
}



// Fonction niveau suivant
void NiveauSuivant (void)
{
	unsigned char i=0;
	unsigned char Bravo [8] = {' ', 'B','R','A','V','O','!',' '};
	unsigned char Niveau [8] = {' ','n','i','v','e','a','u',' '};
	unsigned char Suivant [8] = {' ','s','u','i','v','a','n','t'};
	unsigned char Vert [8] = {' ',' ','v','e','r','t',' ',' '};

	LCD_GotoXY(12,3); 
	for (i=0; i<8; i++)
		LCD_Putchar(Bravo[i]);
	LCD_GotoXY(0,6);
	for (i=0; i<8; i++)
		LCD_Putchar(Niveau[i]);
	LCD_GotoXY(0,7);
	for (i=0; i<8; i++)
		LCD_Putchar(Suivant[i]);
	LCD_GotoXY(64,7);
	for (i=0; i<8; i++)
		LCD_Putchar(Vert[i]);
}




// Niveau 1
void Level1 (void) 
{

	unsigned char Xcaisse=0;
	unsigned char Ycaisse=0;
	unsigned char Xjoueur=0;
	unsigned char Yjoueur=0;


// Contour du level1
// ligne de 67 pixels 8pixels*8 cases+ 4pixels (2 de chaque cots)
	TraceHori (31, 98, 23);
// ligne de 67 pixels 8pixels*8 cases+ 4pixels (2 de chaque cots)
	TraceHori (31, 98, 32);
	TraceVert (24, 32, 31);
	TraceVert (24, 32, 97);

// Positionne la cible
// Debut du lieu de la cible a creer
	LCD_GotoXY (89,3);
	CreerObjet(Cible);
// Positionne la caisse
// Debutdu lieu de la caisse a creer
	Xcaisse=40;
	Ycaisse=3;
	LCD_GotoXY (Xcaisse, Ycaisse);
	CreerObjet(Caisse);
// Positionne le joueur
// Debut du lieu du joueur a creer
	Xjoueur = 32;
	Yjoueur = 3;
	LCD_GotoXY (Xjoueur, Yjoueur);
	CreerObjet(Joueur);
	
	
	do {
// Si le joystick est boug vers la gauche
		if (Joystick_X () > 156){
// Si le joueur n'est pas au bout du plateau
			if (Xjoueur!=32){
// Effacer le joueur
				EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur dans la case d'avant
				Xjoueur=Xjoueur-8;
				BougerObjet (Xjoueur, Yjoueur, Joueur);	
				Delay10KTCYx(1000);	
			}
		}

// si le joystick est boug vers la droite
		if (Joystick_X () < -156){
// et si la caisse n'est pas au bout du plateau
			if ((Xcaisse!=88) && (Xjoueur == (Xcaisse-8))){
// Effacer le joueur et la caisse
				EffacerObjet (Xjoueur, Yjoueur, Joueur);
				EffacerObjet(Xcaisse, Ycaisse, Caisse);
// Placer le joueur et la caisse la case d'aprs
				Xjoueur=Xjoueur+8;
				Xcaisse=Xcaisse+8;
				BougerObjet (Xjoueur, Yjoueur, Joueur);
				BougerObjet (Xcaisse, Ycaisse, Caisse);
				Delay10KTCYx(1000);	
			}
			else {
				if (Xjoueur !=80){
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					Xjoueur=Xjoueur+8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);
					Delay10KTCYx(1000);	
				}
			}
		}


// si la caisse est dans la cible
		if (Xcaisse==88)
			return (0);
	}while (RedButton);
}




// Niveau 2
void Level2(void){
	
	unsigned char Xcaisse1=0;
	unsigned char Ycaisse1=0;
	unsigned char Xcaisse2=0;
	unsigned char Ycaisse2=0;
	unsigned char Xjoueur=0;
	unsigned char Yjoueur=0;


// Contour du niveau
// Ligne de 42pixels 8pixels*5case + 1 de chaque cot  la ligne 8
	TraceHori (19, 61, 7);	
// Ligne de 25pixels 8pixels*3case  la ligne 17
	TraceHori (19, 43, 16);
// Ligne de 9pixels 8pixels*1case + 1  gauche  la ligne 49
	TraceHori (52, 61, 40);
// Ligne de 9pixels 8pixels*1case + 1 de chaque cot  la ligne 49
	TraceHori (43, 53, 56);

	TraceVert (14, 15, 19);
	TraceVert (17, 54, 43);
	TraceVert (40, 55, 52);
	TraceVert (14, 40, 60);


// Positionne la cible 1
// Debut du lieu de la cible a creer
	LCD_GotoXY (44,6);
	CreerObjet(Cible);
// Positionne la cible 2
// Debut du lieu de la cible a creer
	LCD_GotoXY (52,4);
	CreerObjet(Cible);
// Positionne la caisse1
// Debutdu lieu de la caisse a creer
	Xcaisse1=44;
	Ycaisse1=2;
	LCD_GotoXY (Xcaisse1, Ycaisse1);
	CreerObjet(Caisse);
// Positionne la caisse2
// Debutdu lieu de la caisse a creer
	Xcaisse2=52;
	Ycaisse2=2;
	LCD_GotoXY (Xcaisse2, Ycaisse2);
	CreerObjet(Caisse);
// Positionne le joueur
// Debut du lieu du joueur a creer
	Xjoueur = 20;
	Yjoueur = 1;
	LCD_GotoXY (Xjoueur, Yjoueur);
	CreerObjet(Joueur);



	do {

// afficher en boucle le joueur et la cible  -> pour quand ils sont superposs
	LCD_GotoXY (44,6);
	CreerObjet(Cible);	// cible 1
	LCD_GotoXY (52,4);
	CreerObjet(Cible);	// cible 2
	LCD_GotoXY (Xjoueur, Yjoueur);
	CreerObjet(Joueur);
	LCD_GotoXY (Xcaisse1, Ycaisse1);	// caisse1
	CreerObjet(Caisse);
	LCD_GotoXY (Xcaisse2, Ycaisse2);	// caisse2
	CreerObjet(Caisse);


//-------- Si le joystick est boug vers la gauche -------//
		if (Joystick_X () > 156){
// Si le joueur est au bout du plateau ou si une caisse se trouve avant le joueur en bout de plateau-> on ne fait rien
			if ((Xjoueur==20 && Yjoueur==1) || (Xjoueur==44 && Yjoueur!=1) || (Xjoueur==Xcaisse1+8 && Yjoueur==Ycaisse1 && Yjoueur!=1) || (Xcaisse1==20));

			else {
				if (Xcaisse1==Xjoueur-8 && Ycaisse1==Yjoueur){
// Effacer le joueur et la caisse 1
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse1, Ycaisse1, Caisse);
// Placer le joueur  la case d'avant
					Xjoueur=Xjoueur-8;
					Xcaisse1=Xcaisse1-8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					BougerObjet (Xcaisse1, Ycaisse1, Caisse);	
					Delay10KTCYx(1000);	
				}
				else {
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case d'avant
					Xjoueur=Xjoueur-8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					Delay10KTCYx(1000);	
				}
			}
		}



//-------- si le joystick est boug vers la droite --------//
		if (Joystick_X () <-156){
// Si le joueur est au bout du plateau ou si une caisse se trouve aprs le joueur en bout de plateau -> on ne fait rien
			if ((Xjoueur==52 && Yjoueur!=5) || (Xjoueur==44 && (Yjoueur==5 || Yjoueur ==6)) || (Xjoueur==Xcaisse2-8 && Yjoueur==Ycaisse2)); 
			else {
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case suivante
					Xjoueur=Xjoueur+8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);
					Delay10KTCYx(1000);	
			}
		}



//--------n Si le joystick est boug vers le bas --------//
		if(Joystick_Y()<-156){
// si le joueur est au bout du plateau  -> on ne fait rien
			if ((Xjoueur==20|| Xjoueur==28 || Xjoueur==36) && Yjoueur==1);

// si le joueur est au dessus de la caisse 1
			if ((Yjoueur==Ycaisse1-1) && Xjoueur==44){
// Si on est pas au bout du plateau pour la caisse 1
				if (Ycaisse1!=6){
// Effacer le joueur et la caisse1
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse1, Ycaisse1, Caisse);
// Placer le joueur et la caisse  la case suivante
					Yjoueur=Yjoueur+1;
					Ycaisse1=Ycaisse1+1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);
					BougerObjet (Xcaisse1, Ycaisse1, Caisse);
					Delay10KTCYx(1000);	
				}
			}
// s'il n'y a pas de caisse1 sous le joueur
			else{
				if (Yjoueur!=6 && Xjoueur==44){
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case suivante
					Yjoueur=Yjoueur+1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);
					Delay10KTCYx(1000);			
				}
			}
		
// ou si le joueur est au dessus de la caisse 2
			if ((Yjoueur==Ycaisse2-1) &&  Xjoueur==52){
// Si on est pas au bout du plateau
				if (Ycaisse2!=4){
// Effacer le joueur et la caisse2
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse2, Ycaisse2, Caisse);
// Placer le joueur et la caisse  la case suivante
					Yjoueur=Yjoueur+1;
					Ycaisse2=Ycaisse2+1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);
					BougerObjet (Xcaisse2, Ycaisse2, Caisse);
					Delay10KTCYx(1000);	
				}
			}
// s'il n'y a pas de caisse2 sous le joueur
			else{
				if (Yjoueur!=4 && Xjoueur==52){
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case suivante
					Yjoueur=Yjoueur+1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);
					Delay10KTCYx(1000);			
				}
			}

		}




//-------- Si le Joystick est boug vers le haut --------//
		if(Joystick_Y()>156){
// Si le joueur est en haut du plateau  -> on ne fait rien
			if (Yjoueur==1);

// si le joueur est sous la caisse 1 et la caisse 1 n'est pas en haut du plateau
			if (Yjoueur==Ycaisse1+1 && Xjoueur==44){
				if (Ycaisse1!=1){
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse1, Ycaisse1, Caisse);
// Placer le joueur  la case suivante
					Yjoueur=Yjoueur-1;
					Ycaisse1=Ycaisse1-1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);
					BougerObjet (Xcaisse1, Ycaisse1, Caisse);
					Delay10KTCYx(1000);
				}
			}
// s'il n'y a pas de caisse1 sur le joueur
			else{
				if (Yjoueur!=1 && Xjoueur==44){
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case suivante
					Yjoueur=Yjoueur-1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);
					Delay10KTCYx(1000);			
				}
			}

// si le joueur est sous la caisse 2 et la caisse 2 n'est pas en haut du plateau
			if (Yjoueur==Ycaisse2+1 && Xjoueur==52){
				if (Ycaisse2!=1){
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse2, Ycaisse2, Caisse);
// Placer le joueur  la case suivante
					Yjoueur=Yjoueur-1;
					Ycaisse2=Ycaisse2-1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);
					BougerObjet (Xcaisse2, Ycaisse2, Caisse);
					Delay10KTCYx(1000);
				}
			}
// s'il n'y a pas de caisse2 sur le joueur
			else{
				if (Yjoueur!=1 && Xjoueur==52){
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case suivante
					Yjoueur=Yjoueur-1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);
					Delay10KTCYx(1000);	
				}
			}
		}

// si les deux caisses sont dans leurs cibles
		if ((Xcaisse1==44 && Ycaisse1==6) && (Xcaisse2==52 && Ycaisse2 ==4))
			return (0);
	}while (RedButton);
}




// Niveau 3 
void Level3(void) {
	unsigned char Xcaisse=0;
	unsigned char Ycaisse=0;
	unsigned char Xjoueur=0;
	unsigned char Yjoueur=0;
 
// Contour du niveau
	TraceHori(38,56,7);
	TraceHori(6,38,15);
	TraceHori(6,46,24);
	TraceHori(14,32,39);
	TraceHori(56,64,39);
	TraceHori(32,47,47);
	TraceHori(24,64,56);
//	TraceHori(15,24,63);

//ligne 1
	TraceVert(16,23,6);
// ligne 2
	TraceVert(47,63,14); 
//ligne 3
	TraceVert(56,63,23);
//ligne 4
	TraceVert(40,48,31);
// ligne5
	TraceVert(8,16,38);
//ligne 6
	TraceVert(24,48,46);
//ligne 7
	TraceVert(8,40,55);
//ligne 8
	TraceVert(40,56,63);


// Positionne la cible
// Debut du lieu de la cible a creer
	LCD_GotoXY (15,7);
	CreerObjet(Cible);
// Positionne la caisse
// Debutdu lieu de la caisse a creer
	Xcaisse=15;
	Ycaisse=2;
	LCD_GotoXY (Xcaisse, Ycaisse);
	CreerObjet(Caisse);
// Positionne le joueur
// Debut du lieu du joueur a creer
	Xjoueur = 7;
	Yjoueur = 2;
	LCD_GotoXY (Xjoueur, Yjoueur);
	CreerObjet(Joueur);



	do{
//-------- si le joystick est boug vers la gauche -------//
		if (Joystick_X() > 156){

// Si la caisse est  gauche du joueur
			if (Xcaisse==Xjoueur-8 && Ycaisse==Yjoueur){
// Si la caisse n'est pas au bout du plateau
				if (Xcaisse!=15){
// Effacer le joueur et la caisse 
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse, Ycaisse, Caisse);
// Placer le joueur  la case aprs
					Xjoueur=Xjoueur-8;
					Xcaisse=Xcaisse-8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					BougerObjet (Xcaisse, Ycaisse, Caisse);	
					Delay10KTCYx(1000);
				}
			}
// si le joueur est seul
			else {
// si le joueur est au bout du plateau -> on ne fait rien
				if ((Xjoueur==7 && Yjoueur==2) 
				|| (Xjoueur==15 && (Yjoueur==5 || Yjoueur==6 || Yjoueur==7)) 
				|| (Xjoueur==39 && Yjoueur==1) 
				|| (Xjoueur==47 && (Yjoueur==3 || Yjoueur==4 || Yjoueur==5)) );
				else {
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case aprs
					Xjoueur=Xjoueur-8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);		
					Delay10KTCYx(1000);
				}
			}
		}



//-------- Si le joystick est boug vers la droite --------//
		if (Joystick_X() <-156){


// Si la caisse est  droite du joueur
			if (Xcaisse==Xjoueur+8 && Ycaisse==Yjoueur){
// Si la caisse n'est pas au bout du plateau
				if (Xcaisse!=47){
// Effacer le joueur et la caisse 
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse, Ycaisse, Caisse);
// Placer le joueur  la case aprs
					Xjoueur=Xjoueur+8;
					Xcaisse=Xcaisse+8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					BougerObjet (Xcaisse, Ycaisse, Caisse);	
					Delay10KTCYx(1000);
				}
			}
// si le joueur est seul
			else {
// si le joueur n'est pas au bout du plateau
				if ((Xjoueur==47 && (Yjoueur==1 || Yjoueur==2 || Yjoueur==3 || Yjoueur==4 ))
				|| (Xjoueur==55 &&(Yjoueur==5 || Yjoueur==6))
				|| (Xjoueur==23 && Yjoueur==5) );
				else {
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case aprs
					Xjoueur=Xjoueur+8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);		
					Delay10KTCYx(1000);
				}
			}
		}


//------- Si le joystick est boug vers le haut --------//
		if (Joystick_Y()>156){
// Si le joueur est au bout du plateau -> on ne fait rien
			if ((Yjoueur==2 && (Xjoueur==7 || Xjoueur==15 ||Xjoueur==23 || Xjoueur==31))
			|| (Yjoueur==1 && (Xjoueur==39 || Xjoueur==47)) 
			|| (Yjoueur==5 && (Xjoueur==15 || Xjoueur==23 || Xjoueur==55))
			|| (Yjoueur==6 && (Xjoueur==31 || Xjoueur==39)) );

			else {
// Effacer le joueur 
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case au dessus
					Yjoueur=Yjoueur-1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);		
					Delay10KTCYx(1000);
			}
		}


//------- Si le joueur est boug vers le bas --------//
		if (Joystick_Y()<-156){

// si le joueur est au dessus de la caisse
			if ((Yjoueur==Ycaisse-1) && (Xcaisse==Xjoueur)){
// si la caisse n'est pas au bout du plateau
				if (Ycaisse!=6){
// Effacer le joueur et la caisse
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse, Ycaisse, Caisse);
// Placer le joueur  la case au dessus
					Yjoueur=Yjoueur+1;
					Ycaisse=Ycaisse+1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					BougerObjet (Xcaisse, Ycaisse, Caisse);	
					Delay10KTCYx(1000);	
				}
// si la caisse est en position X15 et Y6
				if (Xcaisse==15 && Ycaisse==6){
// Effacer le joueur et la caisse
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse, Ycaisse, Caisse);
// Placer le joueur  la case au dessus
					Yjoueur=Yjoueur+1;
					Ycaisse=Ycaisse+1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					BougerObjet (Xcaisse, Ycaisse, Caisse);	
					Delay10KTCYx(1000);	
				}
			}
// si le joueur est seul
			else {
// Si le joueur est au bout du plateau -> on ne fait rien
				if ((Yjoueur==2 && (Xjoueur==7 || Xjoueur==15 ||Xjoueur==23 || Xjoueur==31 || Xjoueur==39))
				|| (Yjoueur==6 && Xjoueur!=15) );
				else {
// Effacer le joueur et la caisse
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case au dessus
					Yjoueur=Yjoueur+1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					Delay10KTCYx(1000);
				}
			}
		}

// Si la caisse est dans la cible
		if (Xcaisse==15 && Ycaisse==7)
			return (0);
	}while (RedButton);
}



//Niveau 4
void Level4 (void){

	unsigned char i;
	unsigned char Xcaisse=0;
	unsigned char Ycaisse=0;
	unsigned char Xjoueur=0;
	unsigned char Yjoueur=0;

// Tracer contour du niveau
	TraceHori(7, 57, 7);
	TraceHori(7, 15, 16);
	TraceHori(24, 39, 16);
	TraceHori(24, 39, 31);
	TraceHori(24, 39, 40);
	TraceHori(24, 39, 55);
	TraceHori(48, 57, 40);
	TraceHori(48, 65, 55);

	TraceVert(10, 16, 7);
	TraceVert(16, 63, 15);
	TraceVert(16, 32, 24);
	TraceVert(16, 32, 39);
	TraceVert(40, 55, 24);
	TraceVert(40, 55, 39);
	TraceVert(8, 40, 56);
	TraceVert(40, 56, 48);
	TraceVert(56, 63, 64);

// Remplissage des deux rectangles au milieux du plateau
	for (i=17; i<31; i++){
		TraceHori(24,39,i);
	}
	for (i=41; i<56; i++){
		TraceHori(24,39,i);
	}


// Positionne la cible
// Debut du lieu de la cible a creer
	LCD_GotoXY (56,7);
	CreerObjet(Cible);
// Positionne la caisse
// Debutdu lieu de la caisse a creer
	Xcaisse=40;
	Ycaisse=2;
	LCD_GotoXY (Xcaisse, Ycaisse);
	CreerObjet(Caisse);
// Positionne le joueur
// Debut du lieu du joueur a creer
	Xjoueur = 8;
	Yjoueur = 1;
	LCD_GotoXY (Xjoueur, Yjoueur);
	CreerObjet(Joueur);


	do {

// afficher en boucle le joueur et la cible  -> pour quand ils sont superposs
	LCD_GotoXY (56,7);
	CreerObjet(Cible);
	LCD_GotoXY (Xjoueur, Yjoueur);
	CreerObjet(Joueur);



//-------- Si le joystick est boug vers la droite --------//
		if (Joystick_X() <-156){

// Si la caisse est  droite du joueur
			if (Xcaisse==Xjoueur+8 && Ycaisse==Yjoueur){
// Si la caisse est au bout du plateau -> on ne fait rien
				if (Xcaisse==48 && (Ycaisse==1 || Ycaisse==2 || Ycaisse==3 || Ycaisse==4)
				|| (Xcaisse==56 && Ycaisse==7));
				else {
// Effacer le joueur et la caisse 
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse, Ycaisse, Caisse);
// Placer le joueur  la case aprs
					Xjoueur=Xjoueur+8;
					Xcaisse=Xcaisse+8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					BougerObjet (Xcaisse, Ycaisse, Caisse);	
					Delay10KTCYx(1000);
				}
			}
// si le joueur est seul
			else {
// si le joueur n'est pas au bout du plateau
				if ((Xjoueur==48 && (Yjoueur==1 || Yjoueur==2 || Yjoueur==3 || Yjoueur==4 ))
				|| (Xjoueur==40 &&(Yjoueur==5 || Yjoueur==6))
				|| (Xjoueur==16 && (Yjoueur==2|| Yjoueur==3 || Yjoueur==5 || Yjoueur==6))
				|| (Xjoueur==56 && Yjoueur==7) );
				else {
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case aprs
					Xjoueur=Xjoueur+8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);		
					Delay10KTCYx(1000);
				}
			}
		}


//-------- si le joystick est boug vers la gauche -------//
		if (Joystick_X() > 156){

// Si la caisse est  gauche du joueur
			if (Xcaisse==Xjoueur-8 && Ycaisse==Yjoueur){
// Si la caisse est au bout du plateau -> on ne fait rien
				if ( (Xcaisse==16 && (Ycaisse==4 || Ycaisse==7))
				|| Xcaisse==8 
				|| (Xcaisse==40 && (Ycaisse==2 || Ycaisse==3 || Ycaisse==5 || Ycaisse==6)) );
				else {
// Effacer le joueur et la caisse 
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse, Ycaisse, Caisse);
// Placer le joueur  la case aprs
					Xjoueur=Xjoueur-8;
					Xcaisse=Xcaisse-8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					BougerObjet (Xcaisse, Ycaisse, Caisse);	
					Delay10KTCYx(1000);
				}
			}
// si le joueur est seul
			else {
// si le joueur est au bout du plateau -> on ne fait rien
				if ((Xjoueur==8 && Yjoueur==1) 
				|| (Xjoueur==16 && (Yjoueur==2 || Yjoueur==3 || Yjoueur==4 || Yjoueur==5 || Yjoueur==6)) 
				|| (Xjoueur==40 && (Yjoueur==2 || Yjoueur==3 || Yjoueur==5 || Yjoueur==6)) );
				else {
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case aprs
					Xjoueur=Xjoueur-8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);		
					Delay10KTCYx(1000);
				}
			}
		}



//------- Si le joystick est boug vers le haut --------//
		if (Joystick_Y()>156){

// si le joueur est dessous de la caisse
			if ((Yjoueur==Ycaisse+1) && (Xcaisse==Xjoueur)){
// si la caisse est au bout du plateau -> on ne fait
				if (Ycaisse!=1){
// Effacer le joueur et la caisse
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse, Ycaisse, Caisse);
// Placer le joueur  la case au dessus
					Yjoueur=Yjoueur-1;
					Ycaisse=Ycaisse-1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					BougerObjet (Xcaisse, Ycaisse, Caisse);	
					Delay10KTCYx(1000);	
				}
			}

// Si le joueur est seul
			else {
// Si le joueur est au bout du plateau -> on ne fait rien
				if ((Yjoueur==1)
			|| (Yjoueur==4 && (Xjoueur==24 || Xjoueur==32)) 
			|| (Yjoueur==7 && (Xjoueur==24 || Xjoueur==32 || Xjoueur==48 || Xjoueur==56)) );

				else {
// Effacer le joueur 
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case au dessus
					Yjoueur=Yjoueur-1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);		
					Delay10KTCYx(1000);
				}
			}
		}





//------- Si le joueur est boug vers le bas --------//
		if (Joystick_Y()<-156){

// si le joueur est au dessus de la caisse
			if ((Yjoueur==Ycaisse-1) && (Xcaisse==Xjoueur)){
// si la caisse n'est pas au bout du plateau
				if (Ycaisse!=7){
// Effacer le joueur et la caisse
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
					EffacerObjet (Xcaisse, Ycaisse, Caisse);
// Placer le joueur  la case au dessus
					Yjoueur=Yjoueur+1;
					Ycaisse=Ycaisse+1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					BougerObjet (Xcaisse, Ycaisse, Caisse);	
					Delay10KTCYx(1000);	
				}
			}
// si le joueur est seul
			else {
// Si le joueur est au bout du plateau -> on ne fait rien
				if ((Yjoueur==1 && (Xjoueur==8 || Xjoueur==24 || Xjoueur==32))
				|| (Yjoueur==4 && (Xjoueur==24 || Xjoueur==32 || Xjoueur==48))
				|| (Yjoueur==7) );
				else {
// Effacer le joueur et la caisse
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case au dessus
					Yjoueur=Yjoueur+1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					Delay10KTCYx(1000);
				}
			}
		}

// si la caisse est dans la cible
		if (Xcaisse==56 && Ycaisse==7)
			return (0);
	}while (RedButton);

}




//niveau 5
void Level5 (void){
	unsigned char i=0;	
	unsigned char Xcaisse1=0;
	unsigned char Ycaisse1=0;
	unsigned char Xcaisse2=0;
	unsigned char Ycaisse2=0;
	unsigned char Xcaisse3=0;
	unsigned char Ycaisse3=0;
	unsigned char Xjoueur=0;
	unsigned char Yjoueur=0;

// Tracer contour du niveau
	TraceHori(23, 41, 7);
	TraceHori(7, 23, 23);
	TraceHori(40, 49, 23);
	TraceHori(7, 15, 40);
	TraceHori(40, 49, 40);
	TraceHori(15, 41, 56);
	TraceHori(24, 31, 40);
	TraceHori(24, 31, 47);

	TraceVert(10, 24, 23);
	TraceVert(10, 24, 40);
	TraceVert(24, 40, 7);
	TraceVert(24, 40, 48);
	TraceVert(40, 56, 15);
	TraceVert(40, 56, 40);
	TraceVert(40, 47, 24);
	TraceVert(40, 47, 31);

// Remplissage du rectangle au milieux du plateau
	for (i=40; i<47; i++){
		TraceHori(24,31,i);
	}

// Positionne la cible1
// Debut du lieu de la cible a creer
	LCD_GotoXY (32,1);
	CreerObjet(Cible);
// Positionne la cible2
// Debut du lieu de la cible a creer
	LCD_GotoXY (32,6);
	CreerObjet(Cible);
// Positionne la cible3
// Debut du lieu de la cible a creer
	LCD_GotoXY (16,6);
	CreerObjet(Cible);
// Positionne la caisse1
// Debutdu lieu de la caisse1 a creer
	Xcaisse1=16;
	Ycaisse1=3;
	LCD_GotoXY (Xcaisse1, Ycaisse1);
	CreerObjet(Caisse);
// Positionne la caisse2
// Debutdu lieu de la caisse2 a creer
	Xcaisse2=24;
	Ycaisse2=3;
	LCD_GotoXY (Xcaisse2, Ycaisse2);
	CreerObjet(Caisse);
// Positionne la caisse3
// Debutdu lieu de la caisse3 a creer
	Xcaisse3=16;
	Ycaisse3=5;
	LCD_GotoXY (Xcaisse3, Ycaisse3);
	CreerObjet(Caisse);
// Positionne le joueur
// Debut du lieu du joueur a creer
	Xjoueur = 24;
	Yjoueur = 6;
	LCD_GotoXY (Xjoueur, Yjoueur);
	CreerObjet(Joueur);



	do {

// afficher en boucle le joueur et les cibles  -> pour quand ils sont superposs
	LCD_GotoXY (32,1);
	CreerObjet(Cible);			// cible 1
	LCD_GotoXY (32,6);
	CreerObjet(Cible);			// cible 2
	LCD_GotoXY (16,6);
	CreerObjet(Cible);			// cible 3
	LCD_GotoXY (Xjoueur, Yjoueur);
	CreerObjet(Joueur);
	LCD_GotoXY (Xcaisse1, Ycaisse1);
	CreerObjet(Caisse);			// caisse1
	LCD_GotoXY (Xcaisse2, Ycaisse2);
	CreerObjet(Caisse);			// caisse2
	LCD_GotoXY (Xcaisse3, Ycaisse3);
	CreerObjet(Caisse);			// caisse3



//-------- Si le joystick est boug vers la droite --------//
		if (Joystick_X() <-156){

// Si la caisse 1 est  droite du joueur
			if (Xcaisse1==Xjoueur+8 && Ycaisse1==Yjoueur) {
// Si la caisse est au bout du plateau -> on ne fait rien
				if ((Xcaisse1==32  && (Ycaisse1==1 || Ycaisse1==2 || Ycaisse1==6))
				|| (Xcaisse1==40 && (Ycaisse1==3 || Ycaisse1==4)));
				else {
// si une caisse est coll  la premiere  -> on ne fait rien
					if ((Xcaisse1==Xcaisse2-8 && Ycaisse1==Ycaisse2) 
					|| (Xcaisse1==Xcaisse3-8 && Ycaisse1==Ycaisse3) );
					else {
// Effacer le joueur et la caisse 
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse1, Ycaisse1, Caisse);
// Placer le joueur  la case aprs
						Xjoueur=Xjoueur+8;
						Xcaisse1=Xcaisse1+8;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse1, Ycaisse1, Caisse);	
						Delay10KTCYx(1000);
					}
				}
			}
			
// Si la caisse est  droite du joueur
			if(Xcaisse2==Xjoueur+8 && Ycaisse2==Yjoueur) {
// Si la caisse est au bout du plateau -> on ne fait rien
				if ((Xcaisse2==32  && (Ycaisse2==1 || Ycaisse2==2 || Ycaisse2==6))
				|| (Xcaisse2==40 && (Ycaisse2==3 || Ycaisse2==4)) );
				else {
// si une caissse est coll  la premiere  -> on ne fait rien
					if ((Xcaisse2==Xcaisse1-8 && Ycaisse2==Ycaisse1) 
					|| (Xcaisse2==Xcaisse3-8 && Ycaisse2==Ycaisse3) );
					else {
// Effacer le joueur et la caisse 
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse2, Ycaisse2, Caisse);
// Placer le joueur  la case aprs
						Xjoueur=Xjoueur+8;
						Xcaisse2=Xcaisse2+8;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse2, Ycaisse2, Caisse);	
						Delay10KTCYx(1000);
					}
				}
			}
			
			
// Si la caisse est  droite du joueur
			if (Xcaisse3==Xjoueur+8 && Ycaisse3==Yjoueur){
// Si la caisse est au bout du plateau -> on ne fait rien
				if ((Xcaisse3==32  && (Ycaisse3==1 || Ycaisse3==2 || Ycaisse3==6))
				|| (Xcaisse3==40 && (Ycaisse3==3 || Ycaisse3==4)) );
				else {
// si une caissse est coll  la premiere  -> on ne fait rien
					if ((Xcaisse3==Xcaisse2-8 && Ycaisse3==Ycaisse2) 
					|| (Xcaisse3==Xcaisse1-8 && Ycaisse3==Ycaisse1) );
					else {
// Effacer le joueur et la caisse 
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse3, Ycaisse3, Caisse);
// Placer le joueur  la case aprs
						Xjoueur=Xjoueur+8;
						Xcaisse3=Xcaisse3+8;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse3, Ycaisse3, Caisse);	
						Delay10KTCYx(1000);
					}
				}
			}
// si le joueur est seul
			else {
// si le joueur n'est pas au bout du plateau
				if ((Xjoueur==32 && (Yjoueur==1 || Yjoueur==2 || Yjoueur==5 || Yjoueur==6 ))
				|| (Xjoueur==40 &&(Yjoueur==3 || Yjoueur==4))
				|| (Xjoueur==16 && Yjoueur==5) );
				else {
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case aprs
					Xjoueur=Xjoueur+8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);		
					Delay10KTCYx(1000);
				}
			}
		}


//-------- si le joystick est boug vers la gauche -------//
		if (Joystick_X() > 156){

// Si la caisse1 est  gauche du joueur
			if (Xcaisse1==Xjoueur-8 && Ycaisse1==Yjoueur){
// Si la caisse est au bout du plateau -> on ne fait rien
				if ((Xcaisse1==8  && (Ycaisse1==3 || Ycaisse1==4))
				|| (Xcaisse1==16 && Ycaisse1==6)
				|| (Xcaisse1==24 && (Ycaisse1==1 || Ycaisse1==2)));
				else {
// si une caissse est coll  la premiere  -> on ne fait rien
					if ((Xcaisse1==Xcaisse2+8 && Ycaisse1==Ycaisse2) 
					|| (Xcaisse1==Xcaisse3+8 && Ycaisse1==Ycaisse3) );
					else {
// Effacer le joueur et la caisse 
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse1, Ycaisse1, Caisse);
// Placer le joueur  la case aprs
						Xjoueur=Xjoueur-8;
						Xcaisse1=Xcaisse1-8;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse1, Ycaisse1, Caisse);	
						Delay10KTCYx(1000);
					}
				}
			}
			
			
// Si la caisse2 est  gauche du joueur
			if (Xcaisse2==Xjoueur-8 && Ycaisse2==Yjoueur) {
// Si la caisse est au bout du plateau -> on ne fait rien
				if ((Xcaisse2==8  && (Ycaisse2==3 || Ycaisse2==4))
				|| (Xcaisse2==16 && Ycaisse2==6)
				|| (Xcaisse2==24 && (Ycaisse2==1 || Ycaisse2==2)) );
				else {
// si le joueur est  cot de la caisse 2
					if (Xcaisse2==Xjoueur-8 && Ycaisse2==Yjoueur){
// si une caissse est coll  la premiere  -> on ne fait rien
						if ((Xcaisse2==Xcaisse1+8 && Ycaisse2==Ycaisse1) 
						|| (Xcaisse2==Xcaisse3+8 && Ycaisse2==Ycaisse3) );
						else {
// Effacer le joueur et la caisse 
							EffacerObjet (Xjoueur, Yjoueur, Joueur);
							EffacerObjet (Xcaisse2, Ycaisse2, Caisse);
// Placer le joueur  la case aprs
							Xjoueur=Xjoueur-8;
							Xcaisse2=Xcaisse2-8;
							BougerObjet (Xjoueur, Yjoueur, Joueur);	
							BougerObjet (Xcaisse2, Ycaisse2, Caisse);	
							Delay10KTCYx(1000);
						}
					}
				}
			}
			
			
			
// Si la caisse 3est  gauche du joueur
			if (Xcaisse3==Xjoueur-8 && Ycaisse3==Yjoueur){
// Si la caisse est au bout du plateau -> on ne fait rien
				if ((Xcaisse3==8  && (Ycaisse3==3 || Ycaisse3==4))
				|| (Xcaisse3==16 && Ycaisse3==6) 
				|| (Xcaisse3==24 && (Ycaisse3==1 || Ycaisse3==2)) );
				else {
// si une caissse est coll  la premiere  -> on ne fait rien
					if ((Xcaisse3==Xcaisse2+8 && Ycaisse3==Ycaisse2) 
					|| (Xcaisse3==Xcaisse1+8 && Ycaisse3==Ycaisse1) );
					else {
// Effacer le joueur et la caisse 
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse3, Ycaisse3, Caisse);
// Placer le joueur  la case aprs
						Xjoueur=Xjoueur-8;
						Xcaisse3=Xcaisse3-8;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse3, Ycaisse3, Caisse);	
						Delay10KTCYx(1000);
					}
				}
			}
// si le joueur est seul
			else {
// si le joueur n'est pas au bout du plateau
				if ((Xjoueur==8 && (Yjoueur==3 || Yjoueur==4 ))
				|| (Xjoueur==16 &&(Yjoueur==5 || Yjoueur==6))
				|| (Xjoueur==24 && (Yjoueur==1 || Yjoueur==2))
				|| (Xjoueur==32 && Yjoueur==5) );
				else {
// Effacer le joueur
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case aprs
					Xjoueur=Xjoueur-8;
					BougerObjet (Xjoueur, Yjoueur, Joueur);		
					Delay10KTCYx(1000);
				}
			}
		}



//------- Si le joystick est boug vers le haut --------//
		if (Joystick_Y()>156){

// si le joueur est dessous de la caisse 1
			if ((Yjoueur==Ycaisse1+1) && (Xcaisse1==Xjoueur)){
// si la caisse est au bout du plateau -> on ne fait
				if ( (Ycaisse1==1 && (Xcaisse1==24 || Xcaisse1==32))
				|| (Ycaisse1==3 && (Xcaisse1==8 || Xcaisse1==16 || Xcaisse1==40)));
				else{
// si une caissse est coll  la premiere  -> on ne fait rien
					if ((Ycaisse1==Ycaisse2-1 && Xcaisse1==Xcaisse2) 
					|| (Ycaisse1==Ycaisse3-1 && Xcaisse1==Xcaisse3) );
					else {
// Effacer le joueur et la caisse
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse1, Ycaisse1, Caisse);
// Placer le joueur  la case au dessus
						Yjoueur=Yjoueur-1;
						Ycaisse1=Ycaisse1-1;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse1, Ycaisse1, Caisse);	
						Delay10KTCYx(1000);	
					}
				}
			}

// Si on est sous la caisse 2
			if ((Yjoueur==Ycaisse2+1) && (Xcaisse2==Xjoueur)){			
// si la caisse est au bout du plateau -> on ne fait
				if ((Ycaisse2==1 && (Xcaisse2==24 || Xcaisse2==32))
				|| (Ycaisse2==3 && (Xcaisse2==8 || Xcaisse2==16 || Xcaisse2==40)));
				else{
// si une caissse est coll  la premiere  -> on ne fait rien
					if ((Ycaisse2==Ycaisse1-1 && Xcaisse2==Xcaisse1) 
					|| (Ycaisse2==Ycaisse3-1 && Xcaisse2==Xcaisse3) );
					else {
// Effacer le joueur et la caisse
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse2, Ycaisse2, Caisse);
// Placer le joueur  la case au dessus
						Yjoueur=Yjoueur-1;
						Ycaisse2=Ycaisse2-1;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse2, Ycaisse2, Caisse);	
						Delay10KTCYx(1000);					
					}
				}
			}
			
// si le joueur est dessous de la caisse 3
			if ((Yjoueur==Ycaisse3+1) && (Xcaisse3==Xjoueur)) {
// si la caisse est au bout du plateau -> on ne fait
				if ((Ycaisse3==1 && (Xcaisse3==24 || Xcaisse3==32))
				|| (Ycaisse3==3 && (Xcaisse3==8 || Xcaisse3==16 || Xcaisse3==40)) );
				else{

// si une caissse est coll  la premiere  -> on ne fait rien
					if ((Ycaisse3==Ycaisse2-1 && Xcaisse3==Xcaisse2) 
					|| (Ycaisse3==Ycaisse1-1 && Xcaisse3==Xcaisse1) );
					else {
// Effacer le joueur et la caisse
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse3, Ycaisse3, Caisse);
// Placer le joueur  la case au dessus
						Yjoueur=Yjoueur-1;
						Ycaisse3=Ycaisse3-1;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse3, Ycaisse3, Caisse);	
						Delay10KTCYx(1000);	
					}
				}
			}			


// Si le joueur est seul
			else {
// Si le joueur est au bout du plateau -> on ne fait rien
				if ((Yjoueur==1 && (Xjoueur==24 || Xjoueur==32))
				|| (Yjoueur==3 && (Xjoueur==8 || Xjoueur==16 || Xjoueur==40)) 
				|| (Yjoueur==6 && Xjoueur==24) );

				else {
// Effacer le joueur 
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case au dessus
					Yjoueur=Yjoueur-1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);		
					Delay10KTCYx(1000);
				}
			}
		}





//------- Si le joueur est boug vers le bas --------//
		if (Joystick_Y()<-156){

// si le joueur est au dessus de la caisse 1
			if ((Yjoueur==Ycaisse1-1) && (Xcaisse1==Xjoueur)){
// si la caisse n'est pas au bout du plateau
				if (Ycaisse1==6  
				|| (Ycaisse1==4 && (Xcaisse1==8 || Xcaisse1==24 || Xcaisse1==40 )) );

				else{
// si une caissse est coll  la premiere  -> on ne fait rien
					if ((Ycaisse1==Ycaisse2+1 && Xcaisse1==Xcaisse2) 
					|| (Ycaisse1==Ycaisse3+1 && Xcaisse1==Xcaisse3) );
					else {
// Effacer le joueur et la caisse
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse1, Ycaisse1, Caisse);
// Placer le joueur  la case au dessus
						Yjoueur=Yjoueur+1;
						Ycaisse1=Ycaisse1+1;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse1, Ycaisse1, Caisse);	
						Delay10KTCYx(1000);	
					}
				}
			}
			
// si le joueur est au dessus de la caisse2
			else if ((Yjoueur==Ycaisse2-1) && (Xcaisse2==Xjoueur)){
// si la caisse n'est pas au bout du plateau
				if (Ycaisse2==6 
				|| (Ycaisse2==4 && (Xcaisse2==8 || Xcaisse2==24 || Xcaisse2==40 )));

				else{
// si une caissse est coll  la premiere  -> on ne fait rien
					if ((Ycaisse2==Ycaisse1+1 && Xcaisse2==Xcaisse1) 
					|| (Ycaisse2==Ycaisse3+1 && Xcaisse2==Xcaisse3) );
					else {
// Effacer le joueur et la caisse
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse2, Ycaisse2, Caisse);
// Placer le joueur  la case au dessus
						Yjoueur=Yjoueur+1;
						Ycaisse2=Ycaisse2+1;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse2, Ycaisse2, Caisse);	
						Delay10KTCYx(1000);	
					}
				}
			}
			
// si le joueur est au dessus de la caisse 3
			else if ((Yjoueur==Ycaisse3-1) && (Xcaisse3==Xjoueur)) {
// si la caisse n'est pas au bout du plateau
				if (Ycaisse3==6 
				|| (Ycaisse3==4 && (Xcaisse3==8 || Xcaisse3==24 || Xcaisse3==40 )) );
				else{
// si une caissse est coll  la premiere  -> on ne fait rien
					if ((Ycaisse3==Ycaisse2+1 && Xcaisse3==Xcaisse2) 
					|| (Ycaisse3==Ycaisse1+1 && Xcaisse3==Xcaisse1) );
					else {
// Effacer le joueur et la caisse
						EffacerObjet (Xjoueur, Yjoueur, Joueur);
						EffacerObjet (Xcaisse3, Ycaisse3, Caisse);
// Placer le joueur  la case au dessus
						Yjoueur=Yjoueur+1;
						Ycaisse3=Ycaisse3+1;
						BougerObjet (Xjoueur, Yjoueur, Joueur);	
						BougerObjet (Xcaisse3, Ycaisse3, Caisse);	
						Delay10KTCYx(1000);	
					}
				}
			}
// si le joueur est seul
			else {
// Si le joueur est au bout du plateau -> on ne fait rien
				if ((Yjoueur==4 && (Xjoueur==8 || Xjoueur==24 || Xjoueur==40))
				|| (Yjoueur==6 && (Xjoueur==16 || Xjoueur==24 || Xjoueur==32)) );
				else {
// Effacer le joueur et la caisse
					EffacerObjet (Xjoueur, Yjoueur, Joueur);
// Placer le joueur  la case au dessus
					Yjoueur=Yjoueur+1;
					BougerObjet (Xjoueur, Yjoueur, Joueur);	
					Delay10KTCYx(1000);
				}
			}
		}

// si les trois caisses sont dans leurs cibles
		if (Xcaisse3==16 && Ycaisse3==6 && Xcaisse2==32 && Ycaisse2==6 && Xcaisse1==31 && Ycaisse1==1)
			return (0);




	}while (RedButton);

}
